# babel-origin [![license | Public Domain](https://img.shields.io/badge/license-Public_Domain-blue.svg)](https://creativecommons.org/publicdomain/zero/1.0)

> :milky_way: Babel seamless integration

## Introduction

[babel-origin](https://github.com/aymericbeaumet/babel-origin) allows to easily
setup Babel, similar to how it used to be set back in the time of Babel 5. The
following features work out of the box with 0 configuration:
- [Latest ECMAScript preset](https://babeljs.io/docs/plugins/preset-latest/)
- [Stage 0](https://babeljs.io/docs/plugins/preset-stage-0/) features
- [React](https://facebook.github.io/react/) with [JSX](https://facebook.github.io/jsx/)
- Exposing the [CommonJS modules](https://babeljs.io/docs/plugins/transform-es2015-modules-commonjs/) for the convenience of Node.js developers
- [Code minification](https://github.com/babel/babili) when setting `BABEL_ENV=production`

Also the Babel configuration is exposed in a standard way, so all the external tools will be able to use it as usual, to name a few:
- [Ava](https://github.com/avajs/ava/)
- [Jest](https://github.com/facebook/jest/)
- [Webpack](https://webpack.github.io/)

All of this with a [*single line of code*](#usage)!

## Installation

```bash
$ npm install -D babel-origin
```

## Usage

Add the following to your `package.json`:

```json
{
  "babel": { "extends": "babel-origin" }
}
```

Then it just works!

```json
{
  "scripts": {
    "prepublish": "babel src --out-dir=lib"
  }
}
```

### Customization

If the need arises to extend the configuration, you still have total control:

```json
{
  "babel": {
    "extends": "babel-origin",
    "comments": false
  }
}
```

## External tools

### Ava

Add this to your `package.json`:

```json
{
  "ava": {
    "require": [
      "babel-register"
    ],
    "babel": "inherit"
  }
}
```

### Jest

Working out of the box!

### Webpack

Add this to your Webpack configuration.

```js
module: {
  loaders: [
    {
      test: /\.js$/,
      exclude: /node_modules/,
      loader: 'babel-loader'
    }
  ]
}
```

### Others

Basically all the tools will still work the same as for a basic Babel setup.
See [the official documentation](https://babeljs.io/docs/setup/) for more
information.

## Issues

If you face any issue, please report it on the [bug
tracker](https://github.com/aymericbeaumet/babel-origin/issues).

## Contributing

If you want to improve this software by adding new features, or fixing bugs,
please [fork the project](https://github.com/aymericbeaumet/babel-origin)
and create a [pull
request](https://github.com/aymericbeaumet/babel-origin/pulls).

## Changelog

- 1.1.0
  - Add code minification through [Babili](https://github.com/babel/babili/)

- 1.0.0
  - Stable version

## License

[Creative Commons — CC0 1.0 Universal](http://creativecommons.org/publicdomain/zero/1.0)

To the extent possible under law, [Aymeric Beaumet](https://aymericbeaumet.com)
has waived all copyright and related or neighboring rights to this work.
